Crate namada_vm_env

Crate namada_vm_env 

This crate contains the WASM VM low-level interface.

Modules

tx
Transaction environment imports
vp
Validity predicate environment imports

Structs

KeyVal
Key-value pair represents data from account’s subspace. It is used for prefix iterator’s WASM host_env functions.

Enums

HostEnvResult
A result of a wasm call to host functions that may fail.

Functions

read_from_buffer
This function is a helper to handle the second step of reading var-len values from the host.
read_key_val_bytes_from_buffer
This function is a helper to handle the second step of reading var-len values in a key-value pair from the host.