This crate contains the WASM VM low-level interface.
Modules
Structs
- KeyVal
- Key-value pair represents data from account’s subspace. It is used for prefix iterator’s WASM host_env functions.
Enums
- Host
EnvResult - A result of a wasm call to host functions that may fail.
Functions
- read_
from_ buffer - This function is a helper to handle the second step of reading var-len values from the host.
- read_
key_ val_ bytes_ from_ buffer - This function is a helper to handle the second step of reading var-len values in a key-value pair from the host.